@@ -67,6 +67,9 @@ void IMPersonsDataSource::Private::onAllKnownContactsChanged(const Tp::Contacts
         connect(ktpContact.data(), SIGNAL(presenceChanged(Tp::Presence)),
                 q, SLOT(onContactChanged()));
 
+        connect(ktpContact.data(), SIGNAL(blockStatusChanged(bool)),
+                q, SLOT(onContactChanged()));
+
         connect(ktpContact.data(), SIGNAL(capabilitiesChanged(Tp::ContactCapabilities)),
                 q, SLOT(onContactChanged()));
 
@@ -84,6 +87,8 @@ IMPersonsDataSource::IMPersonsDataSource(QObject *parent, const QVariantList &da
     : BasePersonsDataSource(parent)
     , d(new Private)
 {
+    Q_UNUSED(data);
+
     d->q = this;
     Tp::registerTypes();
 
